==> leoo_junpro-1.0.1.tar.gz: lib/leooflagjunpro/leoonetjunpro/leoohttpmanagerjunpro.dart <==
import 'package:dio/dio.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leooappconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoonetjunpro/leooapphostjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoonetjunpro/leoocodejunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoonetjunpro/leoointerceptorsjunpro/leooerrorinterceptorjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoonetjunpro/leoointerceptorsjunpro/leooheaderinterceptorjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoonetjunpro/leoointerceptorsjunpro/leoologinterceptorjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoonetjunpro/leoointerceptorsjunpro/leooresponseinterceptorjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoonetjunpro/leooresultdatajunpro.dart';
import 'package:mmoo_carrier_info/mmoo_carrier_info.dart';

///http请求
class LeooHttpManagerJunPro {
  static const leooTypeJsonJunPro = 'application/json;charset=utf-8';

  final Dio _dio = Dio(); // 使用默认配置

  LeooHttpManagerJunPro() {
    _dio.interceptors.add(LeooHeaderInterceptorsJunPro());
    _dio.interceptors.add(LeooLogsInterceptorsJunPro());
    _dio.interceptors.add(LeooErrorInterceptorsJunPro());
    _dio.interceptors.add(LeooResponseInterceptorsJunPro());
  }

  ///发起网络请求
  ///[ url] 请求url
  ///[ params] 请求参数
  ///[ header] 外加头
  ///[ option] 配置
  Future<LeooResultDataJunPro> netFetch(
      String url, params, Map<String, dynamic>? header, Options option,
      {bool noTip = false,
      bool cancel = false,
      bool mode = true,
      bool query = false}) async {
    Map<String, dynamic> headers = {
      'content-type': LeooHttpManagerJunPro.leooTypeJsonJunPro
    };
    String cardType;
    try {
      String? carrierInfo = await MmooCarrierInfo.mobileCountryCode;
      if (carrierInfo?.contains('460') == true) {
        cardType = '460';
      } else if (carrierInfo?.isEmpty != false || carrierInfo == 'nil') {
        cardType = '-1';
      } else {
        cardType = carrierInfo ?? '';
      }
    } catch (e) {
      cardType = '-1';
    }
    LeooAppConfigJunPro.leooCardTypeJunPro = cardType;
    if (mode && !LeooAppHostJunPro.leooModeJunPro) {
      cardType = '460';
      LeooAppConfigJunPro.leooCardTypeJunPro = cardType;
    }
    headers['cardtype'] = cardType;
    if (header != null) {
      headers.addAll(header);
    }
    option.headers = headers;
    resultError(DioError e) {
      Response? errorResponse;
      if (e.response != null) {
        errorResponse = e.response;
      } else {
        errorResponse = Response(
            statusCode: LeooCodeJunPro.leooNetErrorJunPro,
            requestOptions: e.requestOptions);
      }
      if (e.type == DioErrorType.connectTimeout ||
          e.type == DioErrorType.receiveTimeout) {
        errorResponse!.statusCode = LeooCodeJunPro.leooNetOutJunPro;
      }
      return LeooResultDataJunPro(e.message, false, errorResponse!.statusCode);
    }

    Response response;
    CancelToken _cancelToken = CancelToken();
    try {
      if (cancel) {
        cancelList.add(_cancelToken);
      }
      if (option.method == 'post') {
        if (query) {
          response = await _dio.request(url,
              queryParameters: params,
              options: option,
              cancelToken: _cancelToken);
        } else {
          response = await _dio.request(url,
              data: params, options: option, cancelToken: _cancelToken);
        }
      } else {
        response = await _dio.request(url,
            queryParameters: params,
            options: option,
            cancelToken: _cancelToken);
      }
    } on DioError catch (e) {
      return resultError(e);
    }
    if (response.data is DioError) {
      return resultError(response.data);
    }
    if (cancel) {
      cancelList.remove(_cancelToken);
    }
    return response.data;
  }

  List<CancelToken> cancelList = [];

  void cancel() {
    for (var element in cancelList) {
      if (element.isCancelled == false) {
        element.cancel();
      }
    }
    cancelList.clear();
  }
}

final LeooHttpManagerJunPro httpManager = LeooHttpManagerJunPro();

==> leoo_junpro-2.0.0.tar.gz: lib/leooflagjunpro/leoonetjunpro/leoohttpmanagerjunpro.dart <==
import 'package:dio/dio.dart';
import 'package:leoo_carrier/leoo_carrier.dart';
import 'package:leoo_junpro/leooflagjunpro/leooappjunpro/leooappconfigjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoonetjunpro/leooapphostjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoonetjunpro/leoocodejunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoonetjunpro/leoointerceptorsjunpro/leooerrorinterceptorjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoonetjunpro/leoointerceptorsjunpro/leooheaderinterceptorjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoonetjunpro/leoointerceptorsjunpro/leoologinterceptorjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoonetjunpro/leoointerceptorsjunpro/leooresponseinterceptorjunpro.dart';
import 'package:leoo_junpro/leooflagjunpro/leoonetjunpro/leooresultdatajunpro.dart';

///http请求
class LeooHttpManagerJunPro {
  static const leooTypeJsonJunPro = 'application/json;charset=utf-8';

  final Dio _dio = Dio(); // 使用默认配置

  LeooHttpManagerJunPro() {
    _dio.interceptors.add(LeooHeaderInterceptorsJunPro());
    _dio.interceptors.add(LeooLogsInterceptorsJunPro());
    _dio.interceptors.add(LeooErrorInterceptorsJunPro());
    _dio.interceptors.add(LeooResponseInterceptorsJunPro());
  }

  ///发起网络请求
  ///[ url] 请求url
  ///[ params] 请求参数
  ///[ header] 外加头
  ///[ option] 配置
  Future<LeooResultDataJunPro> netFetch(
      String url, params, Map<String, dynamic>? header, Options option,
      {bool noTip = false,
      bool cancel = false,
      bool mode = true,
      bool query = false}) async {
    Map<String, dynamic> headers = {
      'content-type': LeooHttpManagerJunPro.leooTypeJsonJunPro
    };
    String cardType;
    try {
      String? carrierInfo = await LeooCarrierInfo.mobileCountryCode;
      if (carrierInfo?.contains('460') == true) {
        cardType = '460';
      } else if (carrierInfo?.isEmpty != false || carrierInfo == 'nil') {
        cardType = '-1';
      } else {
        cardType = carrierInfo ?? '';
      }
    } catch (e) {
      cardType = '-1';
    }
    LeooAppConfigJunPro.leooCardTypeJunPro = cardType;
    if (mode && !LeooAppHostJunPro.leooModeJunPro) {
      cardType = '460';
      LeooAppConfigJunPro.leooCardTypeJunPro = cardType;
    }
    headers['cardtype'] = cardType;
    if (header != null) {
      headers.addAll(header);
    }
    option.headers = headers;
    resultError(DioError e) {
      Response? errorResponse;
      if (e.response != null) {
        errorResponse = e.response;
      } else {
        errorResponse = Response(
            statusCode: LeooCodeJunPro.leooNetErrorJunPro,
            requestOptions: e.requestOptions);
      }
      if (e.type == DioErrorType.connectTimeout ||
          e.type == DioErrorType.receiveTimeout) {
        errorResponse!.statusCode = LeooCodeJunPro.leooNetOutJunPro;
      }
      return LeooResultDataJunPro(e.message, false, errorResponse!.statusCode);
    }

    Response response;
    CancelToken _cancelToken = CancelToken();
    try {
      if (cancel) {
        cancelList.add(_cancelToken);
      }
      if (option.method == 'post') {
        if (query) {
          response = await _dio.request(url,
              queryParameters: params,
              options: option,
              cancelToken: _cancelToken);
        } else {
          response = await _dio.request(url,
              data: params, options: option, cancelToken: _cancelToken);
        }
      } else {
        response = await _dio.request(url,
            queryParameters: params,
            options: option,
            cancelToken: _cancelToken);
      }
    } on DioError catch (e) {
      return resultError(e);
    }
    if (response.data is DioError) {
      return resultError(response.data);
    }
    if (cancel) {
      cancelList.remove(_cancelToken);
    }
    return response.data;
  }

  List<CancelToken> cancelList = [];

  void cancel() {
    for (var element in cancelList) {
      if (element.isCancelled == false) {
        element.cancel();
      }
    }
    cancelList.clear();
  }
}

final LeooHttpManagerJunPro httpManager = LeooHttpManagerJunPro();
